<?php
/**
 * Theme About Page
 *
 * @package Catch_Bells
 * @since 1.0
 */

function catch_bells_theme_page_admin_style( $hook ) {
	if ( 'appearance_page_catch-bells-theme' === $hook ) {
		// Register theme stylesheet.
		$theme_version = wp_get_theme()->get( 'Version' );

		$version_string = is_string( $theme_version ) ? $theme_version : false;
		wp_enqueue_style(
			'catch-bells-theme-admin-style',
			get_theme_file_uri( 'assets/css/about-admin.css' ),
			array(),
			$version_string
		);
	}
}
add_action( 'admin_enqueue_scripts', 'catch_bells_theme_page_admin_style' );

/**
 * Add theme page
 */
function catch_bells_menu() {
	add_theme_page( esc_html__( 'Catch Bells', 'catch-bells' ), esc_html__( 'Catch Bells', 'catch-bells' ), 'edit_theme_options', 'catch-bells-theme', 'catch_bells_theme_page_display' );
}
add_action( 'admin_menu', 'catch_bells_menu' );

/**
 * Display About page
 */
function catch_bells_theme_page_display() {
	$theme = wp_get_theme();
	
	if ( is_child_theme() ) {
		$theme = wp_get_theme()->parent();
	}
	?>
	
	<div id="welcome-panel" class="welcome-panel">
		<div class="welcome-panel-content">
			<div class="welcome-panel-header">
				<h2><?php echo esc_html( $theme->Name ); ?></h2>
				<p><?php esc_html_e( 'Free Full Site Editing WordPress Theme', 'catch-bells' ); ?></p>
			</div>
			
			<div class="welcome-panel-column-container">
				<div class="container-wrap">
					<div class="welcome-panel-column two-columns">
						<!-- <div class="welcome-panel-icon-pages"></div> -->
						<div class="welcome-panel-column-content">
							<h3><?php esc_html_e( 'Getting Started with Catch Bells!', 'catch-bells' ); ?></h3>
							<p><?php esc_html_e( 'Awesome! Catch Bells has been installed and activated successfully. Now, you can start building your dream website with a wide range of highly-customizable block patterns, templates, and template parts available in this astounding theme.', 'catch-bells' ); ?></p>
							<a target="_blank" href="https://catchthemes.com/themes/catch-bells/#theme-instructions"><?php esc_html_e( 'Theme instructions', 'catch-bells' ); ?></a>
						</div>
					</div>
					
					<div class="welcome-panel-column two-columns">
						<div class="welcome-panel-column-content">
							<h3><?php esc_html_e( 'More Features with Catch Bells Pro Theme', 'catch-bells' ); ?></h3>
							<p><?php esc_html_e( 'To get more beautiful block patterns and templates, we recommend you activate the Catch Bells Pro. With the pro theme installed, get more options, blocks, block patterns, templates and template parts.', 'catch-bells' ); ?></p>
							<a target="_blank" class="button green button-primary button-hero green" href="https://catchthemes.com/themes/catch-bells-pro/"><?php esc_html_e( 'Buy Catch Bells Pro', 'catch-bells' ); ?></a>
						</div>
					</div>
					
				</div>
				<div class="sidebar">
					<div class="welcome-panel-column important-links">
					<!-- <div class="welcome-panel-icon-pages"></div> -->
					<div class="welcome-panel-column-content">
						<h3><?php esc_html_e( 'Important Links', 'catch-bells' ); ?></h3>
						<a target="_blank" href="<?php echo esc_url( $theme->get( 'ThemeURI' ) ); ?>"><?php esc_html_e( 'Theme Info', 'catch-bells' ); ?></a>
						<a target="_blank" href="https://fse.catchthemes.com/catch-bells-free"><?php esc_html_e( 'View Demo', 'catch-bells' ); ?></a>
						<a target="_blank" href="<?php echo esc_url( "https://catchthemes.com/fse-faq" ); ?>"><?php esc_html_e( 'FSE FAQs', 'catch-bells' ); ?></a>
						<a  target="_blank" href="<?php echo esc_url( $theme->get( 'ThemeURI' ) . '/#changelog' ); ?>"><?php esc_html_e( 'Change log', 'catch-bells' ); ?></a>
						<a target="_blank" href="<?php echo esc_url( 'https://catchthemes.com/support-forum/forum/full-site-editing/' ); ?>"><?php esc_html_e( 'Support', 'catch-bells' ); ?></a>
					</div>
				</div>
				
				<div class="welcome-panel-column review">
					<!-- <div class="welcome-panel-icon-pages"></div> -->
					<div class="welcome-panel-column-content">
						<h3><?php esc_html_e( 'Leave us a review', 'catch-bells' ); ?></h3>
						<p><?php esc_html_e( 'Loved Catch Bells? Feel free to leave your feedback. Your opinion helps us reach more audiences!', 'catch-bells' ); ?></p>
						<a href="https://wordpress.org/support/theme/catch-bells/reviews/" class="button button-primary button-hero" style="text-decoration: none;" target="_blank"><?php esc_html_e( 'Review', 'catch-bells' ); ?></a>
					</div>
				</div>
				</div>
			</div>
		</div>
	</div>
	<?php
}
